You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2013/04/17 19:38:18 UTC

svn commit: r1469004 [3/11] - in /commons/proper/collections/trunk: ./ src/main/java/org/apache/commons/collections/ src/main/java/org/apache/commons/collections/bag/ src/main/java/org/apache/commons/collections/bidimap/ src/main/java/org/apache/common...

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Transformer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Transformer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Transformer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Transformer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Transformer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Transformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Transformer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 /**
  * Defines a functor interface implemented by classes that transform one

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TransformerUtils.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/TransformerUtils.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TransformerUtils.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TransformerUtils.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/TransformerUtils.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/TransformerUtils.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TransformerUtils.java Wed Apr 17 17:37:03 2013
@@ -14,25 +14,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.util.Collection;
 import java.util.Map;
 
-import org.apache.commons.collections.functors.ChainedTransformer;
-import org.apache.commons.collections.functors.CloneTransformer;
-import org.apache.commons.collections.functors.ClosureTransformer;
-import org.apache.commons.collections.functors.ConstantTransformer;
-import org.apache.commons.collections.functors.EqualPredicate;
-import org.apache.commons.collections.functors.ExceptionTransformer;
-import org.apache.commons.collections.functors.FactoryTransformer;
-import org.apache.commons.collections.functors.InstantiateTransformer;
-import org.apache.commons.collections.functors.InvokerTransformer;
-import org.apache.commons.collections.functors.MapTransformer;
-import org.apache.commons.collections.functors.NOPTransformer;
-import org.apache.commons.collections.functors.PredicateTransformer;
-import org.apache.commons.collections.functors.StringValueTransformer;
-import org.apache.commons.collections.functors.SwitchTransformer;
+import org.apache.commons.collections4.functors.ChainedTransformer;
+import org.apache.commons.collections4.functors.CloneTransformer;
+import org.apache.commons.collections4.functors.ClosureTransformer;
+import org.apache.commons.collections4.functors.ConstantTransformer;
+import org.apache.commons.collections4.functors.EqualPredicate;
+import org.apache.commons.collections4.functors.ExceptionTransformer;
+import org.apache.commons.collections4.functors.FactoryTransformer;
+import org.apache.commons.collections4.functors.InstantiateTransformer;
+import org.apache.commons.collections4.functors.InvokerTransformer;
+import org.apache.commons.collections4.functors.MapTransformer;
+import org.apache.commons.collections4.functors.NOPTransformer;
+import org.apache.commons.collections4.functors.PredicateTransformer;
+import org.apache.commons.collections4.functors.StringValueTransformer;
+import org.apache.commons.collections4.functors.SwitchTransformer;
 
 /**
  * <code>TransformerUtils</code> provides reference implementations and 
@@ -73,7 +73,7 @@ public class TransformerUtils {
      * @param <I>  the input type
      * @param <O>  the output type
      * @return the transformer
-     * @see org.apache.commons.collections.functors.ExceptionTransformer
+     * @see org.apache.commons.collections4.functors.ExceptionTransformer
      */
     public static <I, O> Transformer<I, O> exceptionTransformer() {
         return ExceptionTransformer.<I, O>exceptionTransformer();
@@ -85,7 +85,7 @@ public class TransformerUtils {
      * @param <I>  the input type
      * @param <O>  the output type
      * @return the transformer
-     * @see org.apache.commons.collections.functors.ConstantTransformer
+     * @see org.apache.commons.collections4.functors.ConstantTransformer
      */
     public static <I, O> Transformer<I, O> nullTransformer() {
         return ConstantTransformer.<I, O>nullTransformer();
@@ -98,7 +98,7 @@ public class TransformerUtils {
      * 
      * @param <T>  the input/output type
      * @return the transformer
-     * @see org.apache.commons.collections.functors.NOPTransformer
+     * @see org.apache.commons.collections4.functors.NOPTransformer
      */
     public static <T> Transformer<T, T> nopTransformer() {
         return NOPTransformer.<T>nopTransformer();
@@ -116,7 +116,7 @@ public class TransformerUtils {
      * 
      * @param <T>  the input/output type
      * @return the transformer
-     * @see org.apache.commons.collections.functors.CloneTransformer
+     * @see org.apache.commons.collections4.functors.CloneTransformer
      */
     public static <T> Transformer<T, T> cloneTransformer() {
         return CloneTransformer.<T>cloneTransformer();
@@ -130,7 +130,7 @@ public class TransformerUtils {
      * @param <O>  the output type
      * @param constantToReturn  the constant object to return each time in the transformer
      * @return the transformer.
-     * @see org.apache.commons.collections.functors.ConstantTransformer
+     * @see org.apache.commons.collections4.functors.ConstantTransformer
      */
     public static <I, O> Transformer<I, O> constantTransformer(final O constantToReturn) {
         return ConstantTransformer.constantTransformer(constantToReturn);
@@ -144,7 +144,7 @@ public class TransformerUtils {
      * @param closure  the closure to run each time in the transformer, not null
      * @return the transformer
      * @throws IllegalArgumentException if the closure is null
-     * @see org.apache.commons.collections.functors.ClosureTransformer
+     * @see org.apache.commons.collections4.functors.ClosureTransformer
      */
     public static <T> Transformer<T, T> asTransformer(final Closure<? super T> closure) {
         return ClosureTransformer.closureTransformer(closure);
@@ -158,7 +158,7 @@ public class TransformerUtils {
      * @param predicate  the predicate to run each time in the transformer, not null
      * @return the transformer
      * @throws IllegalArgumentException if the predicate is null
-     * @see org.apache.commons.collections.functors.PredicateTransformer
+     * @see org.apache.commons.collections4.functors.PredicateTransformer
      */
     public static <T> Transformer<T, Boolean> asTransformer(final Predicate<? super T> predicate) {
         return PredicateTransformer.predicateTransformer(predicate);
@@ -173,7 +173,7 @@ public class TransformerUtils {
      * @param factory  the factory to run each time in the transformer, not null
      * @return the transformer
      * @throws IllegalArgumentException if the factory is null
-     * @see org.apache.commons.collections.functors.FactoryTransformer
+     * @see org.apache.commons.collections4.functors.FactoryTransformer
      */
     public static <I, O> Transformer<I, O> asTransformer(final Factory<? extends O> factory) {
         return FactoryTransformer.factoryTransformer(factory);
@@ -188,7 +188,7 @@ public class TransformerUtils {
      * @param transformer2  the second transformer
      * @return the transformer
      * @throws IllegalArgumentException if either transformer is null
-     * @see org.apache.commons.collections.functors.ChainedTransformer
+     * @see org.apache.commons.collections4.functors.ChainedTransformer
      */
     @SuppressWarnings("unchecked")
     public static <T> Transformer<T, T> chainedTransformer(
@@ -205,7 +205,7 @@ public class TransformerUtils {
      * @param transformers  an array of transformers to chain
      * @return the transformer
      * @throws IllegalArgumentException if the transformers array or any of the transformers is null
-     * @see org.apache.commons.collections.functors.ChainedTransformer
+     * @see org.apache.commons.collections4.functors.ChainedTransformer
      */
     public static <T> Transformer<T, T> chainedTransformer(final Transformer<? super T, ? extends T>[] transformers) {
         return ChainedTransformer.chainedTransformer(transformers);
@@ -220,7 +220,7 @@ public class TransformerUtils {
      * @param transformers  a collection of transformers to chain
      * @return the transformer
      * @throws IllegalArgumentException if the transformers collection or any of the transformers is null
-     * @see org.apache.commons.collections.functors.ChainedTransformer
+     * @see org.apache.commons.collections4.functors.ChainedTransformer
      */
     public static <T> Transformer<T, T> chainedTransformer(
             final Collection<? extends Transformer<T, T>> transformers) {
@@ -238,7 +238,7 @@ public class TransformerUtils {
      * @param falseTransformer  the transformer called if the predicate is false
      * @return the transformer
      * @throws IllegalArgumentException if either the predicate or transformer is null
-     * @see org.apache.commons.collections.functors.SwitchTransformer
+     * @see org.apache.commons.collections4.functors.SwitchTransformer
      */
     @SuppressWarnings("unchecked")
     public static <I, O> Transformer<I, O> switchTransformer(final Predicate<? super I> predicate,
@@ -262,7 +262,7 @@ public class TransformerUtils {
      * @throws IllegalArgumentException if the either array is null or empty
      * @throws IllegalArgumentException if any element in the arrays is null
      * @throws IllegalArgumentException if the arrays are different sizes
-     * @see org.apache.commons.collections.functors.SwitchTransformer
+     * @see org.apache.commons.collections4.functors.SwitchTransformer
      */
     public static <I, O> Transformer<I, O> switchTransformer(final Predicate<? super I>[] predicates,
             final Transformer<? super I, ? extends O>[] transformers) {
@@ -285,7 +285,7 @@ public class TransformerUtils {
      * @throws IllegalArgumentException if the either array is null or empty
      * @throws IllegalArgumentException if any element in the arrays is null
      * @throws IllegalArgumentException if the arrays are different sizes
-     * @see org.apache.commons.collections.functors.SwitchTransformer
+     * @see org.apache.commons.collections4.functors.SwitchTransformer
      */
     public static <I, O> Transformer<I, O> switchTransformer(final Predicate<? super I>[] predicates,
             final Transformer<? super I, ? extends O>[] transformers,
@@ -312,7 +312,7 @@ public class TransformerUtils {
      * @throws IllegalArgumentException if the map is null or empty
      * @throws IllegalArgumentException if any transformer in the map is null
      * @throws ClassCastException  if the map elements are of the wrong type
-     * @see org.apache.commons.collections.functors.SwitchTransformer
+     * @see org.apache.commons.collections4.functors.SwitchTransformer
      */
     public static <I, O> Transformer<I, O> switchTransformer(
             final Map<Predicate<I>, Transformer<I, O>> predicatesAndTransformers) {
@@ -334,7 +334,7 @@ public class TransformerUtils {
      * @return the transformer
      * @throws IllegalArgumentException if the map is null or empty
      * @throws IllegalArgumentException if any transformer in the map is null
-     * @see org.apache.commons.collections.functors.SwitchTransformer
+     * @see org.apache.commons.collections4.functors.SwitchTransformer
      */
     @SuppressWarnings("unchecked")
     public static <I, O> Transformer<I, O> switchMapTransformer(
@@ -360,7 +360,7 @@ public class TransformerUtils {
      * 
      * @param <T>  the output type
      * @return the transformer
-     * @see org.apache.commons.collections.functors.InstantiateTransformer
+     * @see org.apache.commons.collections4.functors.InstantiateTransformer
      */
     public static <T> Transformer<Class<? extends T>, T> instantiateTransformer() {
         return InstantiateTransformer.<T>instantiateTransformer();
@@ -376,7 +376,7 @@ public class TransformerUtils {
      * @param args  the arguments to pass to the constructor, can be null
      * @return the transformer
      * @throws IllegalArgumentException if the paramTypes and args don't match
-     * @see org.apache.commons.collections.functors.InstantiateTransformer
+     * @see org.apache.commons.collections4.functors.InstantiateTransformer
      */
     public static <T> Transformer<Class<? extends T>, T> instantiateTransformer(
             final Class<?>[] paramTypes, final Object[] args) {
@@ -391,7 +391,7 @@ public class TransformerUtils {
      * @param <O>  the output type
      * @param map  the map to use to transform the objects
      * @return the transformer, or a {@link ConstantTransformer#NULL_INSTANCE} if the {@code map} is {@code null}
-     * @see org.apache.commons.collections.functors.MapTransformer
+     * @see org.apache.commons.collections4.functors.MapTransformer
      */
     public static <I, O> Transformer<I, O> mapTransformer(final Map<? super I, ? extends O> map) {
         return MapTransformer.mapTransformer(map);
@@ -411,7 +411,7 @@ public class TransformerUtils {
      * @param methodName  the method name to call on the input object, may not be null
      * @return the transformer
      * @throws IllegalArgumentException if the methodName is null.
-     * @see org.apache.commons.collections.functors.InvokerTransformer
+     * @see org.apache.commons.collections4.functors.InvokerTransformer
      */
     public static <I, O> Transformer<I, O> invokerTransformer(final String methodName) {
         return InvokerTransformer.<I, O>invokerTransformer(methodName, null, null);
@@ -429,7 +429,7 @@ public class TransformerUtils {
      * @param args  the arguments
      * @return the transformer
      * @throws IllegalArgumentException if the method name is null or the paramTypes and args don't match
-     * @see org.apache.commons.collections.functors.InvokerTransformer
+     * @see org.apache.commons.collections4.functors.InvokerTransformer
      */
     public static <I, O> Transformer<I, O> invokerTransformer(final String methodName, final Class<?>[] paramTypes,
                                                               final Object[] args) {
@@ -443,7 +443,7 @@ public class TransformerUtils {
      * 
      * @param <T>  the input type
      * @return the transformer
-     * @see org.apache.commons.collections.functors.StringValueTransformer
+     * @see org.apache.commons.collections4.functors.StringValueTransformer
      */
     public static <T> Transformer<T, String> stringValueTransformer() {
         return StringValueTransformer.<T>stringValueTransformer();

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Trie.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Trie.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Trie.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Trie.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Trie.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Trie.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Trie.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.util.Map;
 import java.util.SortedMap;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TrieUtils.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/TrieUtils.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TrieUtils.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TrieUtils.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/TrieUtils.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/TrieUtils.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/TrieUtils.java Wed Apr 17 17:37:03 2013
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
-import org.apache.commons.collections.trie.SynchronizedTrie;
-import org.apache.commons.collections.trie.UnmodifiableTrie;
+import org.apache.commons.collections4.trie.SynchronizedTrie;
+import org.apache.commons.collections4.trie.UnmodifiableTrie;
 
 /**
  * A collection of {@link Trie} utilities.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Unmodifiable.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Unmodifiable.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Unmodifiable.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Unmodifiable.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Unmodifiable.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/Unmodifiable.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/Unmodifiable.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 /**
  * Marker interface for collections, maps and iterators that are unmodifiable.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractBagDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractBagDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractBagDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractBagDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Set;
 
-import org.apache.commons.collections.Bag;
-import org.apache.commons.collections.collection.AbstractCollectionDecorator;
+import org.apache.commons.collections4.Bag;
+import org.apache.commons.collections4.collection.AbstractCollectionDecorator;
 
 /**
  * Decorates another <code>Bag</code> to provide additional behaviour.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -27,8 +27,8 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 
-import org.apache.commons.collections.Bag;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.Bag;
 
 /**
  * Abstract implementation of the {@link Bag} interface to simplify the creation

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractSortedBagDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractSortedBagDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractSortedBagDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/AbstractSortedBagDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Comparator;
 
-import org.apache.commons.collections.SortedBag;
+import org.apache.commons.collections4.SortedBag;
 
 /**
  * Decorates another <code>SortedBag</code> to provide additional behaviour.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/HashBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/HashBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/HashBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/HashBag.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -23,7 +23,7 @@ import java.io.Serializable;
 import java.util.Collection;
 import java.util.HashMap;
 
-import org.apache.commons.collections.Bag;
+import org.apache.commons.collections4.Bag;
 
 /**
  * Implements {@link Bag}, using a {@link HashMap} to provide the

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedBag.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Set;
 
-import org.apache.commons.collections.Bag;
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.collection.PredicatedCollection;
+import org.apache.commons.collections4.Bag;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.collection.PredicatedCollection;
 
 /**
  * Decorates another {@link Bag} to validate that additions

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedSortedBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedSortedBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedSortedBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/PredicatedSortedBag.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Comparator;
 
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.SortedBag;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.SortedBag;
 
 /**
  * Decorates another {@link SortedBag} to validate that additions

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedBag.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Set;
 
-import org.apache.commons.collections.Bag;
-import org.apache.commons.collections.collection.SynchronizedCollection;
+import org.apache.commons.collections4.Bag;
+import org.apache.commons.collections4.collection.SynchronizedCollection;
 
 /**
  * Decorates another {@link Bag} to synchronize its behaviour

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedSortedBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedSortedBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedSortedBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/SynchronizedSortedBag.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Comparator;
 
-import org.apache.commons.collections.Bag;
-import org.apache.commons.collections.SortedBag;
+import org.apache.commons.collections4.Bag;
+import org.apache.commons.collections4.SortedBag;
 
 /**
  * Decorates another {@link SortedBag} to synchronize its behaviour

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedBag.java Wed Apr 17 17:37:03 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Set;
 
-import org.apache.commons.collections.Bag;
-import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TransformedCollection;
-import org.apache.commons.collections.set.TransformedSet;
+import org.apache.commons.collections4.set.TransformedSet;
+import org.apache.commons.collections4.Bag;
+import org.apache.commons.collections4.Transformer;
+import org.apache.commons.collections4.collection.TransformedCollection;
 
 /**
  * Decorates another {@link Bag} to transform objects that are added.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedSortedBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedSortedBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedSortedBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TransformedSortedBag.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.util.Comparator;
 
-import org.apache.commons.collections.SortedBag;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.SortedBag;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Decorates another {@link SortedBag} to transform objects that are added.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TreeBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TreeBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -24,10 +24,10 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.Set;
 
-import org.apache.commons.collections.Bag;
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.iterators.UnmodifiableIterator;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.Bag;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.iterators.UnmodifiableIterator;
 
 /**
  * Decorates another {@link Bag} to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -24,10 +24,10 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.Set;
 
-import org.apache.commons.collections.SortedBag;
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.iterators.UnmodifiableIterator;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.SortedBag;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.iterators.UnmodifiableIterator;
 
 /**
  * Decorates another {@link SortedBag} to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/package-info.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractBidiMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractBidiMapDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
-import org.apache.commons.collections.BidiMap;
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.map.AbstractMapDecorator;
+import org.apache.commons.collections4.BidiMap;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.map.AbstractMapDecorator;
 
 /** 
  * Provides a base decorator that enables additional functionality to be added

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractDualBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractDualBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractDualBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractDualBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections.BidiMap;
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.ResettableIterator;
-import org.apache.commons.collections.collection.AbstractCollectionDecorator;
-import org.apache.commons.collections.iterators.AbstractIteratorDecorator;
-import org.apache.commons.collections.keyvalue.AbstractMapEntryDecorator;
+import org.apache.commons.collections4.BidiMap;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.ResettableIterator;
+import org.apache.commons.collections4.collection.AbstractCollectionDecorator;
+import org.apache.commons.collections4.iterators.AbstractIteratorDecorator;
+import org.apache.commons.collections4.keyvalue.AbstractMapEntryDecorator;
 
 /**
  * Abstract {@link BidiMap} implemented using two maps.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractOrderedBidiMapDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractOrderedBidiMapDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractOrderedBidiMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractOrderedBidiMapDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
-import org.apache.commons.collections.OrderedBidiMap;
-import org.apache.commons.collections.OrderedMapIterator;
+import org.apache.commons.collections4.OrderedBidiMap;
+import org.apache.commons.collections4.OrderedMapIterator;
 
 /** 
  * Provides a base decorator that enables additional functionality to be added

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractSortedBidiMapDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractSortedBidiMapDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractSortedBidiMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractSortedBidiMapDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.util.Comparator;
 import java.util.SortedMap;
 
-import org.apache.commons.collections.SortedBidiMap;
+import org.apache.commons.collections4.SortedBidiMap;
 
 /** 
  * Provides a base decorator that enables additional functionality to be added

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualHashBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualHashBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualHashBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualHashBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -23,7 +23,7 @@ import java.io.Serializable;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.commons.collections.BidiMap;
+import org.apache.commons.collections4.BidiMap;
 
 /**
  * Implementation of {@link BidiMap} that uses two {@link HashMap} instances.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualLinkedHashBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualLinkedHashBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualLinkedHashBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualLinkedHashBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
-import org.apache.commons.collections.BidiMap;
+import org.apache.commons.collections4.BidiMap;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -28,13 +28,13 @@ import java.util.Map;
 import java.util.SortedMap;
 import java.util.TreeMap;
 
-import org.apache.commons.collections.BidiMap;
-import org.apache.commons.collections.OrderedBidiMap;
-import org.apache.commons.collections.OrderedMap;
-import org.apache.commons.collections.OrderedMapIterator;
-import org.apache.commons.collections.ResettableIterator;
-import org.apache.commons.collections.SortedBidiMap;
-import org.apache.commons.collections.map.AbstractSortedMapDecorator;
+import org.apache.commons.collections4.BidiMap;
+import org.apache.commons.collections4.OrderedBidiMap;
+import org.apache.commons.collections4.OrderedMap;
+import org.apache.commons.collections4.OrderedMapIterator;
+import org.apache.commons.collections4.ResettableIterator;
+import org.apache.commons.collections4.SortedBidiMap;
+import org.apache.commons.collections4.map.AbstractSortedMapDecorator;
 
 /**
  * Implementation of {@link BidiMap} that uses two {@link TreeMap} instances.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/TreeBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/TreeBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/TreeBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/TreeBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.util.AbstractSet;
 import java.util.Collection;
@@ -24,16 +24,16 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
 
-import org.apache.commons.collections.KeyValue;
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.OrderedBidiMap;
-import org.apache.commons.collections.OrderedIterator;
-import org.apache.commons.collections.OrderedMapIterator;
-import org.apache.commons.collections.iterators.EmptyOrderedMapIterator;
-import org.apache.commons.collections.keyvalue.UnmodifiableMapEntry;
+import org.apache.commons.collections4.KeyValue;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.OrderedBidiMap;
+import org.apache.commons.collections4.OrderedIterator;
+import org.apache.commons.collections4.OrderedMapIterator;
+import org.apache.commons.collections4.iterators.EmptyOrderedMapIterator;
+import org.apache.commons.collections4.keyvalue.UnmodifiableMapEntry;
 
-import static org.apache.commons.collections.bidimap.TreeBidiMap.DataElement.KEY;
-import static org.apache.commons.collections.bidimap.TreeBidiMap.DataElement.VALUE;
+import static org.apache.commons.collections4.bidimap.TreeBidiMap.DataElement.KEY;
+import static org.apache.commons.collections4.bidimap.TreeBidiMap.DataElement.VALUE;
 
 /**
  * Red-Black tree-based implementation of BidiMap where all objects added
@@ -69,6 +69,8 @@ import static org.apache.commons.collect
  * not allow setValue() and will throw an
  * UnsupportedOperationException on attempts to call that method.
  *
+ * TODO: serialization does not work anymore
+ *
  * @since 3.0 (previously DoubleOrderedMap v2.0)
  * @version $Id$
  */

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections.BidiMap;
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.collection.UnmodifiableCollection;
-import org.apache.commons.collections.iterators.UnmodifiableMapIterator;
-import org.apache.commons.collections.map.UnmodifiableEntrySet;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.BidiMap;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.collection.UnmodifiableCollection;
+import org.apache.commons.collections4.iterators.UnmodifiableMapIterator;
+import org.apache.commons.collections4.map.UnmodifiableEntrySet;
 
 /**
  * Decorates another {@link BidiMap} to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableOrderedBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableOrderedBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableOrderedBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableOrderedBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections.OrderedBidiMap;
-import org.apache.commons.collections.OrderedMapIterator;
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.collection.UnmodifiableCollection;
-import org.apache.commons.collections.iterators.UnmodifiableOrderedMapIterator;
-import org.apache.commons.collections.map.UnmodifiableEntrySet;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.OrderedBidiMap;
+import org.apache.commons.collections4.OrderedMapIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.collection.UnmodifiableCollection;
+import org.apache.commons.collections4.iterators.UnmodifiableOrderedMapIterator;
+import org.apache.commons.collections4.map.UnmodifiableEntrySet;
 
 /**
  * Decorates another {@link OrderedBidiMap} to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableSortedBidiMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableSortedBidiMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableSortedBidiMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/UnmodifiableSortedBidiMap.java Wed Apr 17 17:37:03 2013
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
 
 import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
 
-import org.apache.commons.collections.OrderedMapIterator;
-import org.apache.commons.collections.SortedBidiMap;
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.collection.UnmodifiableCollection;
-import org.apache.commons.collections.iterators.UnmodifiableOrderedMapIterator;
-import org.apache.commons.collections.map.UnmodifiableEntrySet;
-import org.apache.commons.collections.map.UnmodifiableSortedMap;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.OrderedMapIterator;
+import org.apache.commons.collections4.SortedBidiMap;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.collection.UnmodifiableCollection;
+import org.apache.commons.collections4.iterators.UnmodifiableOrderedMapIterator;
+import org.apache.commons.collections4.map.UnmodifiableEntrySet;
+import org.apache.commons.collections4.map.UnmodifiableSortedMap;
 
 /**
  * Decorates another {@link SortedBidiMap} to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/package-info.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractCollectionDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractCollectionDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.io.Serializable;
 import java.util.Collection;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractUntypedCollectionDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractUntypedCollectionDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractUntypedCollectionDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractUntypedCollectionDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.io.Serializable;
 import java.util.Collection;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/CompositeCollection.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/CompositeCollection.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/CompositeCollection.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/CompositeCollection.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.io.Serializable;
 import java.lang.reflect.Array;
@@ -24,9 +24,9 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.commons.collections.iterators.EmptyIterator;
-import org.apache.commons.collections.iterators.IteratorChain;
-import org.apache.commons.collections.list.UnmodifiableList;
+import org.apache.commons.collections4.iterators.EmptyIterator;
+import org.apache.commons.collections4.iterators.IteratorChain;
+import org.apache.commons.collections4.list.UnmodifiableList;
 
 /**
  * Decorates a collection of other collections to provide a single unified view.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/IndexedCollection.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/IndexedCollection.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/IndexedCollection.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/IndexedCollection.java Wed Apr 17 17:37:03 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.util.Collection;
 import java.util.HashMap;
 
-import org.apache.commons.collections.MultiMap;
-import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.map.MultiValueMap;
+import org.apache.commons.collections4.MultiMap;
+import org.apache.commons.collections4.Transformer;
+import org.apache.commons.collections4.map.MultiValueMap;
 
 /**
  * An IndexedCollection is a Map-like view onto a Collection. It accepts a

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/PredicatedCollection.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/PredicatedCollection.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/PredicatedCollection.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/PredicatedCollection.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.util.Collection;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Decorates another {@link Collection} to validate that additions

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/SynchronizedCollection.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/SynchronizedCollection.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/SynchronizedCollection.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/SynchronizedCollection.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.io.Serializable;
 import java.util.Collection;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/TransformedCollection.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/TransformedCollection.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/TransformedCollection.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/TransformedCollection.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Decorates another {@link Collection} to transform objects that are added.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableBoundedCollection.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableBoundedCollection.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableBoundedCollection.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableBoundedCollection.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.util.Collection;
 import java.util.Iterator;
 
-import org.apache.commons.collections.BoundedCollection;
-import org.apache.commons.collections.iterators.UnmodifiableIterator;
+import org.apache.commons.collections4.BoundedCollection;
+import org.apache.commons.collections4.iterators.UnmodifiableIterator;
 
 /**
  * {@link UnmodifiableBoundedCollection} decorates another

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableCollection.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableCollection.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableCollection.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/UnmodifiableCollection.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;
 
 import java.util.Collection;
 import java.util.Iterator;
 
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.iterators.UnmodifiableIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.iterators.UnmodifiableIterator;
 
 /**
  * Decorates another {@link Collection} to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/package-info.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/package-info.java Wed Apr 17 17:37:03 2013
@@ -33,4 +33,4 @@
  * 
  * @version $Id$
  */
-package org.apache.commons.collections.collection;
+package org.apache.commons.collections4.collection;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/BooleanComparator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/BooleanComparator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/BooleanComparator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/BooleanComparator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/BooleanComparator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/BooleanComparator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/BooleanComparator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;
 
 import java.io.Serializable;
 import java.util.Comparator;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparableComparator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ComparableComparator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparableComparator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparableComparator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ComparableComparator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ComparableComparator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparableComparator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;
 
 import java.io.Serializable;
 import java.util.Comparator;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparatorChain.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ComparatorChain.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparatorChain.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparatorChain.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ComparatorChain.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ComparatorChain.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ComparatorChain.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;
 
 import java.io.Serializable;
 import java.util.ArrayList;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/FixedOrderComparator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/FixedOrderComparator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/FixedOrderComparator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/FixedOrderComparator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/FixedOrderComparator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/FixedOrderComparator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/FixedOrderComparator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;
 
 import java.io.Serializable;
 import java.util.Comparator;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/NullComparator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/NullComparator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/NullComparator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/NullComparator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/NullComparator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/NullComparator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/NullComparator.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;
 
 import java.io.Serializable;
 import java.util.Comparator;
 
-import org.apache.commons.collections.ComparatorUtils;
+import org.apache.commons.collections4.ComparatorUtils;
 
 /**
  * A Comparator that will compare nulls to be either lower or higher than

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ReverseComparator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ReverseComparator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ReverseComparator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ReverseComparator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ReverseComparator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/ReverseComparator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/ReverseComparator.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;
 
 import java.io.Serializable;
 import java.util.Comparator;
 
-import org.apache.commons.collections.ComparatorUtils;
+import org.apache.commons.collections4.ComparatorUtils;
 
 /**
  * Reverses the order of another comparator by reversing the arguments

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/TransformingComparator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/TransformingComparator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/TransformingComparator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/TransformingComparator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/TransformingComparator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/TransformingComparator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/TransformingComparator.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;
 
 import java.io.Serializable;
 import java.util.Comparator;
 
-import org.apache.commons.collections.ComparatorUtils;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.ComparatorUtils;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Decorates another Comparator with transformation behavior. That is, the
@@ -32,8 +32,8 @@ import org.apache.commons.collections.Tr
  * @since 2.1
  * @version $Id$
  *
- * @see org.apache.commons.collections.Transformer
- * @see org.apache.commons.collections.comparators.ComparableComparator
+ * @see org.apache.commons.collections4.Transformer
+ * @see org.apache.commons.collections4.comparators.ComparableComparator
  */
 public class TransformingComparator<I, O> implements Comparator<I>, Serializable {
     

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/package-info.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/package-info.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/package-info.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/package-info.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/package-info.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/comparators/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/package-info.java Wed Apr 17 17:37:03 2013
@@ -19,10 +19,10 @@
  * {@link java.util.Comparator Comparator} interface.
  * <p>
  * You may also consider using 
- * {@link org.apache.commons.collections.ComparatorUtils ComparatorUtils},
+ * {@link org.apache.commons.collections4.ComparatorUtils ComparatorUtils},
  * which is a single class that uses static methods to construct instances
  * of the classes in this package.
  * 
  * @version $Id$
  */
-package org.apache.commons.collections.comparators;
+package org.apache.commons.collections4.comparators;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/CommandVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/CommandVisitor.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/CommandVisitor.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/CommandVisitor.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 /** 
  * This interface should be implemented by user object to walk

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/DeleteCommand.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/DeleteCommand.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/DeleteCommand.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/DeleteCommand.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 /**
  * Command representing the deletion of one object of the first sequence.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditCommand.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditCommand.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditCommand.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditCommand.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 /**
  * Abstract base class for all commands used to transform an objects sequence

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditScript.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditScript.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditScript.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/EditScript.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 import java.util.ArrayList;
 import java.util.List;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/InsertCommand.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/InsertCommand.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/InsertCommand.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/InsertCommand.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 /**
  * Command representing the insertion of one object of the second sequence.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/KeepCommand.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/KeepCommand.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/KeepCommand.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/KeepCommand.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 /**
  * Command representing the keeping of one object present in both sequences.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsFinder.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsFinder.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsFinder.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsFinder.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 import java.util.ArrayList;
 import java.util.List;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsHandler.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsHandler.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsHandler.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/ReplacementsHandler.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 import java.util.List;
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TreeBag.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/TreeBag.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -25,7 +25,7 @@ import java.util.Comparator;
 import java.util.SortedMap;
 import java.util.TreeMap;
 
-import org.apache.commons.collections.SortedBag;
+import org.apache.commons.collections4.SortedBag;
 
 /**
  * Implements {@link SortedBag}, using a {@link TreeMap} to provide
@@ -34,7 +34,7 @@ import org.apache.commons.collections.So
  * Order will be maintained among the bag members and can be viewed through the
  * iterator.
  * <p>
  * A {@link org.apache.commons.collections.Bag Bag} stores each object in the collection together with a count
  * of occurrences. Extra methods on the interface allow multiple copies of an
  * object to be added or removed at once. It is important to read the interface
  * javadoc carefully as several methods violate the {@link Collection}
@@ -34,7 +34,7 @@ import org.apache.commons.collections.So
  * iterator.
  * <p>
- * A {@link org.apache.commons.collections.Bag Bag} stores each object in the collection together with a count
+ * A {@link org.apache.commons.collections4.Bag Bag} stores each object in the collection together with a count
  * of occurrences. Extra methods on the interface allow multiple copies of an
  * object to be added or removed at once. It is important to read the interface

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bag/package-info.java Wed Apr 17 17:37:03 2013
@@ -15,8 +15,8 @@
  * limitations under the License.
  */
 /**
  * This package contains implementations of the {@link org.apache.commons.collections.Bag Bag} and 
  * {@link org.apache.commons.collections.SortedBag SortedBag} interfaces.
  * A bag stores an object and a count of the number of occurrences of the object.
  * <p>
  * The following implementations are provided in the package:
@@ -35,4 +35,4 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections.bag;
+package org.apache.commons.collections4.bag;
@@ -15,8 +15,8 @@
  */
 /**
- * This package contains implementations of the {@link org.apache.commons.collections.Bag Bag} and 
- * {@link org.apache.commons.collections.SortedBag SortedBag} interfaces.
+ * This package contains implementations of the {@link org.apache.commons.collections4.Bag Bag} and 
+ * {@link org.apache.commons.collections4.SortedBag SortedBag} interfaces.
  * A bag stores an object and a count of the number of occurrences of the object.
  * <p>

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractBidiMapDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/AbstractBidiMapDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/bidimap/package-info.java Wed Apr 17 17:37:03 2013
@@ -16,9 +16,9 @@
  */
 /**
  * This package contains implementations of the
  * {@link org.apache.commons.collections.BidiMap BidiMap},
  * {@link org.apache.commons.collections.OrderedBidiMap OrderedBidiMap} and 
  * {@link org.apache.commons.collections.SortedBidiMap SortedBidiMap} interfaces.
  * A BidiMap is an extension to Map that allows keys and values to be looked up with equal ease.
  * One example usage is a system communicating to a legacy datasource that must convert codes
  * from the new format to the old format and vice versa.
@@ -38,4 +38,4 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections.bidimap;
+package org.apache.commons.collections4.bidimap;
@@ -16,9 +16,9 @@
 /**
  * This package contains implementations of the
- * {@link org.apache.commons.collections.BidiMap BidiMap},
- * {@link org.apache.commons.collections.OrderedBidiMap OrderedBidiMap} and 
- * {@link org.apache.commons.collections.SortedBidiMap SortedBidiMap} interfaces.
+ * {@link org.apache.commons.collections4.BidiMap BidiMap},
+ * {@link org.apache.commons.collections4.OrderedBidiMap OrderedBidiMap} and 
+ * {@link org.apache.commons.collections4.SortedBidiMap SortedBidiMap} interfaces.
  * A BidiMap is an extension to Map that allows keys and values to be looked up with equal ease.
  * One example usage is a system communicating to a legacy datasource that must convert codes

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractCollectionDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/collection/AbstractCollectionDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================